# Python0To1
Automation Framework Example -- By iTesting

本套代码为图书**<从0到1搭建自动化测试框架：原理、实现与工程实践>**的配套代码，作者蔡超。

本套代码旨在方便购买本图书的读者朋友练习使用，请勿用作他途。


如您在练习过程中有任何问题，欢迎关注微信公众号 **iTesting**， 并留下您的微信号，作者会第一时间联系您解决。

